@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Encode qw(encode_utf8);
 use Crypt::Passphrase::Bcrypt;
@@ -14,10 +14,7 @@ use Crypt::Passphrase::Bcrypt;
 sub make_encode_sub {
   my($class, $col, $args) = @_;
 
-  my $cost = exists $args->{cost} ? $args->{cost} : 8;
-  die("Valid cost is a 1 or 2 digit integer. You used '${cost}'.")
-    unless $cost =~ /^\d\d?$/;
-  $cost = sprintf '%02i', 0 + $cost;
+  my $cost = _get_cost($args->{cost});
 
   my $passphrase = Crypt::Passphrase::Bcrypt->new(
     cost => $cost,
@@ -34,10 +31,7 @@ sub make_encode_sub {
 sub make_check_sub {
   my($class, $col, $args) = @_;
 
-  my $cost = exists $args->{cost} ? $args->{cost} : 8;
-  die("Valid cost is a 1 or 2 digit integer. You used '${cost}'.")
-    unless $cost =~ /^\d\d?$/;
-  $cost = sprintf '%02i', 0 + $cost;
+  my $cost = _get_cost($args->{cost});
 
   my $passphrase = Crypt::Passphrase::Bcrypt->new(
     cost => $cost,
@@ -50,6 +44,19 @@ sub make_check_sub {
   }
 }
 
+sub _get_cost {
+  my ($cost) = @_;
+
+  $cost = defined $cost ? $cost : 8;
+
+  die("Valid cost is a 1 or 2 digit integer. You used '$cost'.")
+    unless $cost =~ /^\d\d?$/;
+
+  $cost = sprintf '%02i', 0 + $cost;
+
+  return $cost;
+}
+
 1;
 
 =pod
@@ -62,11 +69,11 @@ DBIx::Class::EncodedColumn::Crypt::Passphrase::Bcrypt - Crypt::Passphrase::Bcryp
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
-  # Crypt::Passphrase::Bcrypt / cost of 6 / generate check method:
+  # In your database class:
 
   __PACKAGE__->add_columns(
     password => {
@@ -78,13 +85,19 @@ version 0.0101
       encode_check_method => 'check_password',
   });
 
+  # In your program:
+
+  my ($c, $user, $pass) = @_;
+  my $result = $c->schema->resultset('Account')->search({ name => $user })->first;
+  return 1 if $result && $result->check_password($pass);
+
 =head1 DESCRIPTION
 
 Use L<Crypt::Passphrase::Bcrypt> for an encoded password column.
 
 =head1 ENCODE ARGUMENTS
 
-=head2 cost => \d\d?
+=head2 cost
 
 A single or double digit non-negative integer representing the cost of the
 hash function. Defaults to C<8>.
